<?php
/**
 * Naix theme customizer
 *
 * @package Naix
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Naix_Customize {
	/**
	 * Customize settings
	 *
	 * @var array
	 */
	protected $config = array();

	/**
	 * The class constructor
	 *
	 * @param array $config
	 */
	public function __construct( $config ) {
		$this->config = $config;

		if ( ! class_exists( 'Kirki' ) ) {
			return;
		}

		$this->register();

		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * Register settings
	 */
	public function register() {

		/**
		 * Add the theme configuration
		 */
		if ( ! empty( $this->config['theme'] ) ) {
			Kirki::add_config(
				$this->config['theme'], array(
					'capability'  => 'edit_theme_options',
					'option_type' => 'theme_mod',
				)
			);
		}

		/**
		 * Add panels
		 */
		if ( ! empty( $this->config['panels'] ) ) {
			foreach ( $this->config['panels'] as $panel => $settings ) {
				Kirki::add_panel( $panel, $settings );
			}
		}

		/**
		 * Add sections
		 */
		if ( ! empty( $this->config['sections'] ) ) {
			foreach ( $this->config['sections'] as $section => $settings ) {
				Kirki::add_section( $section, $settings );
			}
		}

		/**
		 * Add fields
		 */
		if ( ! empty( $this->config['theme'] ) && ! empty( $this->config['fields'] ) ) {
			foreach ( $this->config['fields'] as $name => $settings ) {
				if ( ! isset( $settings['settings'] ) ) {
					$settings['settings'] = $name;
				}

				Kirki::add_field( $this->config['theme'], $settings );
			}
		}
	}

	/**
	 * Enqueues style and scripts for customizer controls
	 */
	public function enqueue_scripts() {
		wp_add_inline_style( 'customize-controls', 'li.control-section-kirki-default { min-height: unset; }' );
	}

	/**
	 * Get config ID
	 *
	 * @return string
	 */
	public function get_theme() {
		return $this->config['theme'];
	}

	/**
	 * Get customize setting value
	 *
	 * @param string $name
	 *
	 * @return bool|string
	 */
	public function get_option( $name ) {

		$default = $this->get_option_default( $name );

		return get_theme_mod( $name, $default );
	}

	/**
	 * Get default option values
	 *
	 * @param $name
	 *
	 * @return mixed
	 */
	public function get_option_default( $name ) {
		if ( ! isset( $this->config['fields'][ $name ] ) ) {
			return false;
		}

		return isset( $this->config['fields'][ $name ]['default'] ) ? $this->config['fields'][ $name ]['default'] : false;
	}
}

/**
 * This is a short hand function for getting setting value from customizer
 *
 * @param string $name
 *
 * @return bool|string
 */
function naix_get_option( $name ) {
	global $naix_customize;

	$value = false;

	if ( class_exists( 'Kirki' ) ) {
		$value = Kirki::get_option( 'naix', $name );
	} elseif ( ! empty( $naix_customize ) ) {
		$value = $naix_customize->get_option( $name );
	}

	return apply_filters( 'naix_get_option', $value, $name );
}

/**
 * Get default option values
 *
 * @param $name
 *
 * @return mixed
 */
function naix_get_option_default( $name ) {
	global $naix_customize;

	if ( empty( $naix_customize ) ) {
		return false;
	}

	return $naix_customize->get_option_default( $name );
}

/**
 * The custom control class
 */

function naix_kirki_enqueue_scripts() {
	wp_enqueue_style( 'naix-kirki-style', get_template_directory_uri() . '/css/custom-kirki.css', array(), '20170106' );
}

add_action( 'customize_controls_print_styles', 'naix_kirki_enqueue_scripts', 30 );

/**
 * Move some default sections to `general` panel that registered by theme
 *
 * @param object $wp_customize
 */
function naix_customize_modify( $wp_customize ) {
	$wp_customize->get_section( 'title_tagline' )->panel     = 'general';
	$wp_customize->get_section( 'static_front_page' )->panel = 'general';
}

add_action( 'customize_register', 'naix_customize_modify' );

/**
 * Get nav menus
 *
 * @return string
 */
function naix_customizer_get_nav_menus() {

	if ( ! is_admin() ) {
		return;
	}

	$menus = wp_get_nav_menus();
	if ( ! $menus ) {
		return;
	}

	$output = array(
		0 => esc_html__( 'Select Menu', 'naix' ),
	);
	foreach ( $menus as $menu ) {
		$output[ $menu->term_id ] = $menu->name;
	}

	return $output;
}


/**
 * Get customize settings
 *
 * @return array
 */
function naix_customize_settings() {
	/**
	 * Customizer configuration
	 */

	$settings = array(
		'theme' => 'naix',
	);

	$panels = array(
		'general'    => array(
			'priority' => 10,
			'title'    => esc_html__( 'General', 'naix' ),
		),
		'typography' => array(
			'priority' => 20,
			'title'    => esc_html__( 'Typography', 'naix' ),
		),
		// Styling
		'styling'    => array(
			'title'    => esc_html__( 'Styling', 'naix' ),
			'priority' => 30,
		),
		'header'     => array(
			'priority' => 50,
			'title'    => esc_html__( 'Header', 'naix' ),
		),
		'blog'       => array(
			'title'    => esc_html__( 'Blog', 'naix' ),
			'priority' => 80,
		),
		'pages'      => array(
			'title'    => esc_html__( 'Pages', 'naix' ),
			'priority' => 80,
		),
	);

	$sections = array(
		'image_sizes'       => array(
			'title'       => esc_html__( 'Image Sizes', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'general',
		),
		'body_typo'         => array(
			'title'       => esc_html__( 'Body', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'heading_typo'      => array(
			'title'       => esc_html__( 'Heading', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'header_typo'       => array(
			'title'       => esc_html__( 'Header', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'menu_sidebar_typo' => array(
			'title'       => esc_html__( 'Menu Sidebar', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'footer_typo'       => array(
			'title'       => esc_html__( 'Footer', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		// Styling
		'styling_general'   => array(
			'title'       => esc_html__( 'General', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'site_background'   => array(
			'title'       => esc_html__( 'Bacground', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'site_boxed'        => array(
			'title'       => esc_html__( 'Boxed Content', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'color_scheme'      => array(
			'title'       => esc_html__( 'Color Scheme', 'naix' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'logo'              => array(
			'title'       => esc_html__( 'Logo', 'naix' ),
			'description' => '',
			'priority'    => 15,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'header'            => array(
			'title'       => esc_html__( 'Header Layout', 'naix' ),
			'description' => '',
			'priority'    => 20,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'menu_sidebar'      => array(
			'title'       => esc_html__( 'Menu SideBar', 'naix' ),
			'description' => '',
			'priority'    => 20,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'footer'            => array(
			'title'       => esc_html__( 'Footer', 'naix' ),
			'description' => '',
			'priority'    => 60,
			'capability'  => 'edit_theme_options',
		),
		'blog'              => array(
			'title'       => esc_html__( 'General', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'blog',
			'capability'  => 'edit_theme_options',
		),
		'single_post'       => array(
			'title'       => esc_html__( 'Single Post', 'naix' ),
			'description' => '',
			'priority'    => 50,
			'panel'       => 'blog',
			'capability'  => 'edit_theme_options',
		),
		'pages_layout'      => array(
			'title'       => esc_html__( 'Layout', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'pages',
			'capability'  => 'edit_theme_options',
		),
		'page_header_pages' => array(
			'title'       => esc_html__( 'Page Header', 'naix' ),
			'description' => '',
			'priority'    => 20,
			'capability'  => 'edit_theme_options',
			'panel'       => 'pages',
		),
		'404_page'          => array(
			'title'       => esc_html__( '404 Page', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'pages',
			'capability'  => 'edit_theme_options',
		),

	);

	$fields = array(
		// image size
		'image_sizes_default'          => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Image Sizes', 'naix' ),
			'default'  => array(
				'blog_grid',
				'blog_sidebar',
				'blog_masonry',
				'portfolio_free',
				'portfolio_masonry_1',
				'portfolio_masonry_2',
				'portfolio_masonry_3',
				'portfolio_masonry_4',
			),
			'section'  => 'image_sizes',
			'priority' => 20,
			'choices'  => array(
				'blog_grid'           => esc_attr__( 'Blog Grid', 'naix' ),
				'blog_sidebar'        => esc_attr__( 'Blog With Sidebar', 'naix' ),
				'blog_masonry'        => esc_attr__( 'Blog Masonry', 'naix' ),
				'portfolio_free'      => esc_attr__( 'Portfolio Free Style', 'naix' ),
				'portfolio_masonry_1' => esc_attr__( 'Portfolio Masonry 1', 'naix' ),
				'portfolio_masonry_2' => esc_attr__( 'Portfolio Masonry 2', 'naix' ),
				'portfolio_masonry_3' => esc_attr__( 'Portfolio Masonry 3', 'naix' ),
				'portfolio_masonry_4' => esc_attr__( 'Portfolio Masonry 4', 'naix' ),
			),
		),
		'preloader'                    => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Preloader', 'naix' ),
			'default'     => 1,
			'section'     => 'styling_general',
			'priority'    => 10,
			'description' => esc_html__( 'Display a preloader when page is loading.', 'naix' ),
		),
		'back_to_top'                  => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Back To Top', 'naix' ),
			'default'     => 1,
			'section'     => 'styling_general',
			'priority'    => 10,
			'description' => esc_html__( 'Check this to show back to top.', 'naix' ),
		),
		'site_background'              => array(
			'type'        => 'color',
			'label'       => esc_html__( 'Background', 'naix' ),
			'default'     => '',
			'section'     => 'site_background',
			'priority'    => 10,
			'description' => esc_html__( 'This option is used for the homepage.', 'naix' ),
		),
		'site_text_color'              => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Text Color', 'naix' ),
			'section'     => 'site_background',
			'default'     => 'dark',
			'priority'    => 10,
			'choices'     => array(
				'dark'  => esc_html__( 'Dark', 'naix' ),
				'light' => esc_html__( 'Light', 'naix' ),
			),
			'description' => esc_html__( 'This option is used for the homepage.', 'naix' ),
		),
		'boxed_content'                => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Boxed Content', 'naix' ),
			'default'     => 0,
			'section'     => 'site_boxed',
			'priority'    => 10,
			'description' => esc_html__( 'This option is used for the homepage.', 'naix' ),
		),
		// Color Scheme
		'color_scheme'                 => array(
			'type'     => 'radio-image',
			'label'    => esc_html__( 'Base Color Scheme', 'naix' ),
			'default'  => '0',
			'section'  => 'color_scheme',
			'priority' => 10,
			'choices'  => array(
				'0'       => get_template_directory_uri() . '/img/colors/default.jpg',
				'#305e7b' => get_template_directory_uri() . '/img/colors/blue.jpg',
				'#8c3718' => get_template_directory_uri() . '/img/colors/sienna.jpg',
				'#e8ae5c' => get_template_directory_uri() . '/img/colors/lightorange.jpg',
				'#9b6501' => get_template_directory_uri() . '/img/colors/goldenrod.jpg',
				'#ff7a5e' => get_template_directory_uri() . '/img/colors/coral.jpg',
				'#cd3333' => get_template_directory_uri() . '/img/colors/lightred01.jpg',
				'#cc0000' => get_template_directory_uri() . '/img/colors/lightred02.jpg',
				'#ff6666' => get_template_directory_uri() . '/img/colors/pink.jpg',
				'#ca7f09' => get_template_directory_uri() . '/img/colors/gold.jpg',
			),
		),
		'custom_color_scheme'          => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Custom Color Scheme', 'naix' ),
			'default'  => 0,
			'section'  => 'color_scheme',
			'priority' => 10,
		),
		'custom_color'                 => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Color', 'naix' ),
			'default'         => '',
			'section'         => 'color_scheme',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'custom_color_scheme',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		// Typography
		'body_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Body', 'naix' ),
			'section'  => 'body_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => 'regular',
				'font-size'      => '16px',
				'line-height'    => '1.6',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#999',
				'text-transform' => 'none',
			),
		),
		'heading1_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 1', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '36px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'heading2_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 2', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '30px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'heading3_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 3', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '24px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'heading4_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 4', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '18px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'heading5_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 5', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '16px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'heading6_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 6', 'naix' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '700',
				'font-size'      => '12px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'menu_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Menu', 'naix' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '400',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'sub_menu_typo'                => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sub Menu', 'naix' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#666',
				'text-transform' => 'none',
			),
		),
		'menu_sidebar_text_typo'       => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sidebar Text', 'naix' ),
			'section'  => 'menu_sidebar_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '400',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'menu_sidebar_typo'            => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Menu', 'naix' ),
			'section'  => 'menu_sidebar_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '600',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '36px',
				'color'          => '#999',
				'text-transform' => 'none',
			),
		),
		'sub_menu_sidebar_typo'        => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sub Menu', 'naix' ),
			'section'  => 'menu_sidebar_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Cerebri Sans',
				'variant'        => '600',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '24px',
				'color'          => '#999',
				'text-transform' => 'none',
			),
		),
		'footer_text_typo'             => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Footer Text', 'naix' ),
			'section'  => 'footer_typo',
			'priority' => 10,
			'default'  => array(
				'font-family' => 'Cerebri Sans',
				'subsets'     => array( 'latin-ext' ),
				'font-size'   => '16px',
			),
		),
		// Logo
		'logo'                         => array(
			'type'        => 'image',
			'label'       => esc_html__( 'Logo Dark', 'naix' ),
			'description' => esc_html__( 'This logo is used for all site.', 'naix' ),
			'section'     => 'logo',
			'default'     => '',
			'priority'    => 20,
		),
		'logo_light'                   => array(
			'type'        => 'image',
			'label'       => esc_html__( 'Logo Light', 'naix' ),
			'section'     => 'logo',
			'description' => esc_html__( 'This logo is just used for header text color light.', 'naix' ),
			'default'     => '',
			'priority'    => 20,
		),
		'logo_width'                   => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Logo Width(px)', 'naix' ),
			'section'  => 'logo',
			'priority' => 20,
			array(
				'setting'  => 'logo',
				'operator' => '!=',
				'value'    => '',
			),
		),
		'logo_height'                  => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Logo Height(px)', 'naix' ),
			'section'  => 'logo',
			'priority' => 20,
			array(
				'setting'  => 'logo',
				'operator' => '!=',
				'value'    => '',
			),
		),
		'logo_margins'                 => array(
			'type'     => 'spacing',
			'label'    => esc_html__( 'Logo Margin', 'naix' ),
			'section'  => 'logo',
			'priority' => 20,
			'default'  => array(
				'top'    => '0',
				'bottom' => '0',
				'left'   => '0',
				'right'  => '0',
			),
			array(
				'setting'  => 'logo',
				'operator' => '!=',
				'value'    => '',
			),
		),
		// Header layout
		'header_layout'                => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Header Layout', 'naix' ),
			'section'  => 'header',
			'default'  => '1',
			'priority' => 10,
			'choices'  => array(
				'1' => esc_html__( 'Header 1', 'naix' ),
				'2' => esc_html__( 'Header 2', 'naix' ),
				'3' => esc_html__( 'Header 3', 'naix' ),
				'4' => esc_html__( 'Header 4', 'naix' ),
				'5' => esc_html__( 'Header 5', 'naix' ),
			),
		),
		'header_layout_custom'         => array(
			'type'            => 'custom',
			'default'         => esc_html__( 'Go to Appearance > Customizing > Header > Menu SideBar to setting the menu.', 'naix' ),
			'section'         => 'header',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '1', '4' ),
				),
			),
		),
		'header_transparent'           => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Header Transparent', 'naix' ),
			'default'     => 0,
			'section'     => 'header',
			'priority'    => 10,
			'description' => esc_html__( 'Check this to enable header transparent in homepage only.', 'naix' ),
		),
		'header_text_color'            => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Header Text Color', 'naix' ),
			'section'     => 'header',
			'default'     => 'dark',
			'priority'    => 10,
			'choices'     => array(
				'light' => esc_html__( 'Light', 'naix' ),
				'dark'  => esc_html__( 'Dark', 'naix' ),
			),
			'description' => esc_html__( 'Select the header text color for homepage only.', 'naix' ),
		),
		'header_bg_hover'              => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Header Background Hover', 'naix' ),
			'default'         => 1,
			'section'         => 'header',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this to enable background color when hover.', 'naix' ),
			'active_callback' => array(
				array(
					'setting'  => 'header_transparent',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'sticky_header'                => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Sticky Header', 'naix' ),
			'default'  => 0,
			'section'  => 'header',
			'priority' => 10,
		),
		'sticky_header_background'     => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Sticky Header Background', 'naix' ),
			'default'         => 1,
			'section'         => 'header',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this to enable background color for sticky header.', 'naix' ),
			'active_callback' => array(
				array(
					'setting'  => 'sticky_header',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'menu_extras'                  => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Extras', 'naix' ),
			'section'         => 'header',
			'default'         => array( 'cart' ),
			'priority'        => 20,
			'choices'         => array(
				'cart' => esc_html__( 'Cart', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '1', '4' ),
				),
			),
		),
		'header_menu_sidebar'          => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Menu Sidebar', 'naix' ),
			'section'         => 'menu_sidebar',
			'default'         => array( 'language', 'menu', 'socials', 'text' ),
			'priority'        => 10,
			'choices'         => array(
				'language' => esc_html__( 'Language', 'naix' ),
				'menu'     => esc_html__( 'Primary Menu', 'naix' ),
				'socials'  => esc_html__( 'Socials', 'naix' ),
				'text'     => esc_html__( 'Custom Text', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '1', '4' ),
				),
			),
		),
		'menu_sidebar_socials'         => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Socials', 'naix' ),
			'section'         => 'menu_sidebar',
			'priority'        => 10,
			'row_label'       => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Social', 'naix' ),
			),
			'default'         => array(
				array(
					'link_url' => 'https://facebook.com/naix',
				),
				array(
					'link_url' => 'https://twitter.com/naix',
				),
				array(
					'link_url' => 'https://instagram.com/naix',
				),
				array(
					'link_url' => 'https://plus.google.com/naix',
				),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'naix' ),
					'description' => esc_html__( 'Enter the URL for this social', 'naix' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '1', '4' ),
				),
				array(
					'setting'  => 'header_menu_sidebar',
					'operator' => 'contains',
					'value'    => 'socials',
				),
			),
		),
		'menu_sidebar_text'            => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Custom Text', 'naix' ),
			'section'         => 'menu_sidebar',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '1', '4' ),
				),
				array(
					'setting'  => 'header_menu_sidebar',
					'operator' => 'contains',
					'value'    => 'text',
				),
			),
		),
		'header_socials'               => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Socials', 'naix' ),
			'section'         => 'header',
			'priority'        => 10,
			'row_label'       => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Social', 'naix' ),
			),
			'default'         => array(
				array(
					'link_url' => 'https://facebook.com/naix',
				),
				array(
					'link_url' => 'https://twitter.com/naix',
				),
				array(
					'link_url' => 'https://instagram.com/naix',
				),
				array(
					'link_url' => 'https://plus.google.com/naix',
				),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'naix' ),
					'description' => esc_html__( 'Enter the URL for this social', 'naix' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_layout',
					'operator' => 'in',
					'value'    => array( '2', '4', '5' ),
				),
			),
		),

		// Blog
		'blog_layout'                  => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Blog Layout', 'naix' ),
			'default'     => 'grid',
			'section'     => 'blog',
			'priority'    => 10,
			'description' => esc_html__( 'Select default layout for blog page.', 'naix' ),
			'choices'     => array(
				'grid'            => esc_html__( 'Grid', 'naix' ),
				'masonry'         => esc_html__( 'Masonry', 'naix' ),
				'text'            => esc_html__( 'Text', 'naix' ),
				'sidebar-content' => esc_html__( 'Content Sidebar', 'naix' ),
				'content-sidebar' => esc_html__( 'Sidebar Content', 'naix' ),
			),
		),
		'blog_text_desc'               => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Blog Description', 'naix' ),
			'section'         => 'blog',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'blog_layout',
					'operator' => 'in',
					'value'    => array( 'text' ),
				),
			),
		),
		'blog_skin'                    => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Blog Skin', 'naix' ),
			'default'     => 'light',
			'section'     => 'blog',
			'priority'    => 10,
			'description' => esc_html__( 'Select default skin for blog page.', 'naix' ),
			'choices'     => array(
				'light' => esc_html__( 'Light', 'naix' ),
				'gray'  => esc_html__( 'Gray', 'naix' ),
			),
		),
		'blog_excerpt_length'          => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Excerpt Length', 'naix' ),
			'section'         => 'blog',
			'default'         => 30,
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'blog_layout',
					'operator' => 'in',
					'value'    => array( 'masonry', 'sidebar-content', 'content-sidebar' ),
				),
			),
		),
		'blog_nav_type'                => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Type of Navigation', 'naix' ),
			'section'  => 'blog',
			'default'  => 'links',
			'priority' => 20,
			'choices'  => array(
				'links'     => esc_html__( 'Links', 'naix' ),
				'view_more' => esc_html__( 'View More', 'naix' ),
			),
		),
		// Single Post
		'single_post_layout'           => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Single Post Layout', 'naix' ),
			'default'     => 'full-content',
			'section'     => 'single_post',
			'priority'    => 10,
			'description' => esc_html__( 'Select default sidebar for single post.', 'naix' ),
			'choices'     => array(
				'full-content'    => esc_html__( 'Full Content', 'naix' ),
				'sidebar-content' => esc_html__( 'Sidebar Content', 'naix' ),
				'content-sidebar' => esc_html__( 'Content Sidebar', 'naix' ),
			),
		),
		'single_post_style'            => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Single Post Style', 'naix' ),
			'default'  => '1',
			'section'  => 'single_post',
			'priority' => 10,
			'choices'  => array(
				'1' => esc_html__( 'Style 1', 'naix' ),
				'2' => esc_html__( 'Style 2', 'naix' ),
			),
		),
		'single_post_featured_image'   => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Featured Image Type', 'naix' ),
			'default'  => '1',
			'section'  => 'single_post',
			'priority' => 10,
			'choices'  => array(
				'1' => esc_html__( 'Background Image', 'naix' ),
				'2' => esc_html__( 'Image', 'naix' ),
			),
		),
		// Footer
		'footer_layout'                => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Footer Layout', 'naix' ),
			'section'  => 'footer',
			'default'  => '1',
			'priority' => 40,
			'choices'  => array(
				'1' => esc_html__( 'Footer 1', 'naix' ),
				'2' => esc_html__( 'Footer 2', 'naix' ),
				'3' => esc_html__( 'Footer 3', 'naix' ),
				'4' => esc_html__( 'Footer 4', 'naix' ),
				'5' => esc_html__( 'Footer 5', 'naix' ),
				'6' => esc_html__( 'Footer 6', 'naix' ),
				'7' => esc_html__( 'Footer 7', 'naix' ),
			),
		),
		'footer_widget_columns'        => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Columns', 'naix' ),
			'section'         => 'footer',
			'default'         => '6',
			'priority'        => 40,
			'choices'         => array(
				'4' => esc_html__( '4 Columns', 'naix' ),
				'5' => esc_html__( '5 Columns', 'naix' ),
				'6' => esc_html__( '6 Columns', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'footer_layout_custom'         => array(
			'type'            => 'custom',
			'description'     => esc_html__( 'Go to Appearance > Widgets > Footer 1, 2, 3, 4, 5, 6 to add widgets content.', 'naix' ),
			'section'         => 'footer',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => '==',
					'value'    => '1',
				),
			),
		),
		'footer_background'            => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Background Color', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '1', '2', '6', '7' ),
				),
			),
		),
		'footer_transparent'           => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Footer Transparent', 'naix' ),
			'section'         => 'footer',
			'default'         => 1,
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '3', '5' ),
				),
			),
		),
		'footer_fixed'                 => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Footer Fixed', 'naix' ),
			'section'         => 'footer',
			'default'         => 0,
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '3', '5' ),
				),
			),
		),
		'footer_text_color'            => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Text Color', 'naix' ),
			'section'         => 'footer',
			'default'         => 'gray',
			'priority'        => 40,
			'choices'         => array(
				'gray'  => esc_html__( 'Gray', 'naix' ),
				'light' => esc_html__( 'Light', 'naix' ),
				'dark'  => esc_html__( 'Dark', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '1', '2', '3', '5', '6', '7' ),
				),
			),
		),
		'footer_logo'                  => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Footer Logo', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '4' ),
				),
			),
		),
		'footer_extra'                 => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Footer Extra', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '2', '6' ),
				),
			),
		),
		'footer_contact_form_title'    => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Contact Form Title', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '7' ),
				),
			),
		),
		'footer_contact_form'          => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Contact Form 7', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '7' ),
				),
			),
			'choices'         => class_exists( 'Kirki_Helper' ) ? Kirki_Helper::get_posts( array(
				'posts_per_page' => -1,
				'post_type'      => 'wpcf7_contact_form',
			) ) : '',
		),
		'footer_info'                  => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Footer Information', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'description'     => esc_html__( 'Divide information with linebreaks (Enter).', 'naix' ),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '4', '6', '7' ),
				),
			),
		),
		'footer_menu'                  => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Menu', 'naix' ),
			'section'         => 'footer',
			'priority'        => 60,
			'default'         => '',
			'choices'         => naix_customizer_get_nav_menus(),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '6' ),
				),
			),
		),
		'footer_links'                 => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Footer Links', 'naix' ),
			'section'         => 'footer',
			'priority'        => 40,
			'row_label'       => array(
				'type'  => 'text',
				'value' => esc_html__( 'Link', 'naix' ),
			),
			'default'         => array(
				array(
					'link_text' => esc_html__( 'Twitter', 'naix' ),
					'link_url'  => 'https://twitter.com/naix',
				),
				array(
					'link_text' => esc_html__( 'Facebook', 'naix' ),
					'link_url'  => 'https://facebook.com/naix',
				),
				array(
					'link_text' => esc_html__( 'Behance', 'naix' ),
					'link_url'  => 'https://behance.com/naix',
				),
				array(
					'link_text' => esc_html__( 'Dribbble', 'naix' ),
					'link_url'  => 'https://dribbble.com/naix',
				),
			),
			'fields'          => array(
				'link_text' => array(
					'type'    => 'text',
					'label'   => esc_html__( 'Link Text', 'naix' ),
					'default' => '',
				),
				'link_url'  => array(
					'type'    => 'text',
					'label'   => esc_html__( 'Link URL', 'naix' ),
					'default' => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => '==',
					'value'    => '2',
				),
			),
		),
		'footer_copyright'             => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Footer CopyRight', 'naix' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 40,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '2', '3', '4', '5', '6', '7' ),
				),
			),
		),
		'footer_copyright_links'       => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Footer Links and CopyRight', 'naix' ),
			'section'         => 'footer',
			'default'         => '1',
			'priority'        => 40,
			'choices'         => array(
				'1' => esc_html__( 'In a line', 'naix' ),
				'2' => esc_html__( 'In multiple lines', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => '==',
					'value'    => '2',
				),
			),
		),
		'footer_socials'               => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Footer Socials', 'naix' ),
			'section'         => 'footer',
			'priority'        => 40,
			'row_label'       => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Social', 'naix' ),
			),
			'default'         => array(
				array(
					'link_url' => 'https://facebook.com/naix',
				),
				array(
					'link_url' => 'https://twitter.com/naix',
				),
				array(
					'link_url' => 'https://instagram.com/naix',
				),
				array(
					'link_url' => 'https://plus.google.com/naix',
				),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'naix' ),
					'description' => esc_html__( 'Enter the URL for this social', 'naix' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '3', '6', '7' ),
				),
			),
		),
		'bg_404'                       => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Background Image', 'naix' ),
			'section'  => '404_page',
			'default'  => '',
			'priority' => 20,
		),
		'404_header_text'              => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Header Text Color', 'naix' ),
			'section'         => '404_page',
			'default'         => 'dark',
			'priority'        => 10,
			'choices'         => array(
				'light' => esc_html__( 'Light', 'naix' ),
				'dark'  => esc_html__( 'Dark', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'bg_404',
					'operator' => '!=',
					'value'    => '',
				),
			),
		),
		'page_header_pages'            => array(
			'type'        => 'toggle',
			'default'     => 1,
			'label'       => esc_html__( 'Enable Page Header', 'naix' ),
			'section'     => 'page_header_pages',
			'description' => esc_html__( 'Enable to show a page header for pages below the site header', 'naix' ),
			'priority'    => 20,
		),
		'page_header_layout_pages'     => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Page Header Layout', 'naix' ),
			'section'         => 'page_header_pages',
			'default'         => '1',
			'priority'        => 20,
			'choices'         => array(
				'1' => esc_html__( 'Layout 1', 'naix' ),
				'2' => esc_html__( 'Layout 2', 'naix' ),
				'3' => esc_html__( 'Layout 3', 'naix' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'page_header_pages',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'page_header_page_parallax'    => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Enable Parallax', 'naix' ),
			'section'         => 'page_header_pages',
			'default'         => 1,
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_pages',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_layout_pages',
					'operator' => 'in',
					'value'    => array( '2', '3' ),
				),
			),
		),
		'page_header_background_pages' => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Bacground Image', 'naix' ),
			'section'         => 'page_header_pages',
			'default'         => '',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_pages',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'page_header_layout_pages',
					'operator' => 'in',
					'value'    => array( '2', '3' ),
				),
			),
		),

	);

	// Setting fields for Portfolio
	if ( class_exists( 'DRF_Portfolio' ) ) {
		$panels['portfolio'] = array(
			'title'    => esc_html__( 'Portfolio', 'naix' ),
			'priority' => 80,
		);

		$sections['portfolio'] = array(
			'title'       => esc_html__( 'General', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'portfolio',
			'capability'  => 'edit_theme_options',
		);

		$sections['portfolio_desc'] = array(
			'title'       => esc_html__( 'Portfolios Description', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'portfolio',
			'capability'  => 'edit_theme_options',
		);

		$sections['single_portfolio'] = array(
			'title'       => esc_html__( 'Single Portfolio', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'portfolio',
			'capability'  => 'edit_theme_options',
		);

		$fields = array_merge(
			$fields, array(
				// Blog
				'portfolio_layout'                    => array(
					'type'        => 'select',
					'label'       => esc_html__( 'Portfolios Page Layout', 'naix' ),
					'default'     => 'grid',
					'section'     => 'portfolio',
					'priority'    => 10,
					'description' => esc_html__( 'Select default layout for portfolios page.', 'naix' ),
					'choices'     => array(
						'grid'    => esc_html__( 'Grid', 'naix' ),
						'masonry' => esc_html__( 'Masonry', 'naix' ),
						'list'    => esc_html__( 'List', 'naix' ),
						'free'    => esc_html__( 'Free Style', 'naix' ),
					),
				),
				'portfolio_per_page'                  => array(
					'type'        => 'number',
					'label'       => esc_html__( ' Number Per Page', 'naix' ),
					'section'     => 'portfolio',
					'default'     => 6,
					'priority'    => 20,
					'description' => esc_html__( 'Specify how many portfolios you want to show on portfolios page', 'naix' ),
				),
				'portfolio_cats_filter'               => array(
					'type'     => 'toggle',
					'label'    => esc_html__( 'Categories Filter', 'naix' ),
					'default'  => 1,
					'section'  => 'portfolio',
					'priority' => 10,
				),
				'portfolio_cats_number'               => array(
					'type'            => 'number',
					'label'           => esc_html__( 'Categories Number', 'naix' ),
					'default'         => '5',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Enter the number of categories filter.', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_cats_filter',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'portfolio_grid_style'                => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolios Style', 'naix' ),
					'default'         => '1',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Select default style for portfolios page.', 'naix' ),
					'choices'         => array(
						'1' => esc_html__( 'Style 1', 'naix' ),
						'2' => esc_html__( 'Style 2', 'naix' ),
						'3' => esc_html__( 'Style 3', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'grid',
						),
					),
				),
				'portfolio_grid_hover_style'          => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolio Hover Style', 'naix' ),
					'default'         => '1',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Go to portfolio detail to choose background color for custom style.', 'naix' ),
					'choices'         => array(
						'1'      => esc_html__( 'Style 1', 'naix' ),
						'2'      => esc_html__( 'Style 2', 'naix' ),
						'3'      => esc_html__( 'Style 3', 'naix' ),
						'4'      => esc_html__( 'Style 4', 'naix' ),
						'custom' => esc_html__( 'Custom Style', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'grid',
						),
						array(
							'setting'  => 'portfolio_grid_style',
							'operator' => 'in',
							'value'    => array( '2', '3' ),
						),
					),
				),
				'portfolio_free_hover_style'          => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolios Hover Style', 'naix' ),
					'default'         => '1',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Go to portfolio detail to choose background color for custom style.', 'naix' ),
					'choices'         => array(
						'1'      => esc_html__( 'Style 1', 'naix' ),
						'2'      => esc_html__( 'Style 2', 'naix' ),
						'3'      => esc_html__( 'Style 3', 'naix' ),
						'4'      => esc_html__( 'Style 4', 'naix' ),
						'custom' => esc_html__( 'Custom Style', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'free',
						),
					),
				),
				'portfolio_masonry_style'             => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolios Style', 'naix' ),
					'default'         => '1',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Select default style for portfolios page.', 'naix' ),
					'choices'         => array(
						'1' => esc_html__( 'Style 1', 'naix' ),
						'2' => esc_html__( 'Style 2', 'naix' ),
						'3' => esc_html__( 'Style 3', 'naix' ),
						'4' => esc_html__( 'Style 4', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'masonry',
						),
					),
				),
				'portfolio_masonry_hover_style'       => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolios Hover Style', 'naix' ),
					'default'         => '1',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Go to portfolio detail to choose background color for custom style.', 'naix' ),
					'choices'         => array(
						'1'      => esc_html__( 'Style 1', 'naix' ),
						'2'      => esc_html__( 'Style 2', 'naix' ),
						'3'      => esc_html__( 'Style 3', 'naix' ),
						'4'      => esc_html__( 'Style 4', 'naix' ),
						'custom' => esc_html__( 'Custom Style', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'masonry',
						),
						array(
							'setting'  => 'portfolio_masonry_style',
							'operator' => 'in',
							'value'    => array( '1', '2', '3' ),
						),
					),
				),
				'portfolio_full_width'                => array(
					'type'            => 'toggle',
					'label'           => esc_html__( 'Full Width', 'naix' ),
					'default'         => '0',
					'section'         => 'portfolio',
					'priority'        => 10,
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'grid',
						),
					),
				),
				'portfolio_grid_columns'              => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Portfolios Columns', 'naix' ),
					'default'         => '2',
					'section'         => 'portfolio',
					'priority'        => 10,
					'description'     => esc_html__( 'Select default columns for portfolio page.', 'naix' ),
					'choices'         => array(
						'2' => esc_html__( '2 Columns', 'naix' ),
						'3' => esc_html__( '3 Columns', 'naix' ),
						'4' => esc_html__( '4 Columns', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'portfolio_layout',
							'operator' => '==',
							'value'    => 'grid',
						),
					),
				),
				'portfolio_nav_type'                  => array(
					'type'     => 'select',
					'label'    => esc_html__( 'Type of Navigation', 'naix' ),
					'section'  => 'portfolio',
					'default'  => 'view_more',
					'priority' => 20,
					'choices'  => array(
						'view_more' => esc_html__( 'View More', 'naix' ),
						'links'     => esc_html__( 'Links', 'naix' ),
					),
				),
				'enable_portfolio_desc'               => array(
					'type'        => 'toggle',
					'label'       => esc_html__( 'Enable Portfolios Description', 'naix' ),
					'section'     => 'portfolio_desc',
					'default'     => '',
					'description' => esc_html__( 'Enable to show a portfolio description for portfolios page and portfolio category page below the site header', 'naix' ),
					'priority'    => 20,
				),
				'portfolio_desc'                      => array(
					'type'     => 'textarea',
					'label'    => esc_html__( 'Description', 'naix' ),
					'section'  => 'portfolio_desc',
					'default'  => '',
					'priority' => 20,
				),
				'single_portfolio_layout'             => array(
					'type'        => 'select',
					'label'       => esc_html__( 'Single Portfolio Layout', 'naix' ),
					'default'     => '1',
					'section'     => 'single_portfolio',
					'priority'    => 10,
					'description' => esc_html__( 'Select default layout for single portfolio page.', 'naix' ),
					'choices'     => array(
						'1' => esc_html__( 'Layout 1', 'naix' ),
						'2' => esc_html__( 'Layout 2', 'naix' ),
						'3' => esc_html__( 'Layout 3', 'naix' ),
						'4' => esc_html__( 'Layout 4', 'naix' ),
						'5' => esc_html__( 'Layout 5', 'naix' ),
					),
				),
				'single_portfolio_page_header'        => array(
					'type'            => 'toggle',
					'label'           => esc_html__( 'Page Header', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => 1,
					'description'     => esc_html__( 'Check this option to show a page header below the site header', 'naix' ),
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2' ),
						),
					),
				),
				'single_portfolio_page_header_image'  => array(
					'type'            => 'image',
					'label'           => esc_html__( 'Background Image', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => '',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2' ),
						),
						array(
							'setting'  => 'single_portfolio_page_header',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'single_portfolio_header_transparent' => array(
					'type'            => 'toggle',
					'label'           => esc_html__( 'Header Transparent', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => 1,
					'priority'        => 20,
					'description'     => esc_html__( 'Check this option to enable header transparent in this portfolio layout.', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2', '5' ),
						),
					),
				),
				'single_portfolio_attr'               => array(
					'type'            => 'toggle',
					'label'           => esc_html__( 'Portfolio Attributes', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => 1,
					'priority'        => 20,
					'description'     => esc_html__( 'Check this option to show portfolio attributes.', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2', '5' ),
						),
					),
				),
				'single_portfolio_client_text'        => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Client Text', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => esc_html__( 'Client', 'naix' ),
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2', '5' ),
						),
					),
				),
				'single_portfolio_team_text'          => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Team Text', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => esc_html__( 'Team', 'naix' ),
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2', '5' ),
						),
					),
				),
				'single_portfolio_services_text'      => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Services Text', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => esc_html__( 'Services', 'naix' ),
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '1', '2', '5' ),
						),
					),
				),
				'single_portfolio_attr_bg_image'      => array(
					'type'            => 'image',
					'label'           => esc_html__( 'Attributes Background Image', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => '',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
					),
				),
				'single_portfolio_attr_bg_color'      => array(
					'type'            => 'color',
					'label'           => esc_html__( 'Attributes Background Color', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => '',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
					),
				),
				'single_portfolio_attr_text'          => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Attributes Text', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => '',
					'priority'        => 20,
					'choices'         => array(
						'dark'  => esc_html__( 'Dark', 'naix' ),
						'light' => esc_html__( 'Light', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
					),
				),
				'single_portfolio_contact'            => array(
					'type'            => 'toggle',
					'label'           => esc_html__( 'Enable Contact Form', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => 1,
					'priority'        => 20,
					'description'     => esc_html__( 'Check this option to show contact form on the single portfolio', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
					),
				),
				'single_portfolio_contact_title'      => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Contact Title', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => esc_html__( 'Hire Us', 'naix' ),
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
						array(
							'setting'  => 'single_portfolio_contact',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'single_portfolio_contact_form'       => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Contact Form 7', 'naix' ),
					'section'         => 'single_portfolio',
					'default'         => '',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'single_portfolio_layout',
							'operator' => 'in',
							'value'    => array( '2' ),
						),
						array(
							'setting'  => 'single_portfolio_contact',
							'operator' => '==',
							'value'    => 1,
						),
					),
					'choices'         => class_exists( 'Kirki_Helper' ) ? Kirki_Helper::get_posts( array(
						'posts_per_page' => -1,
						'post_type'      => 'wpcf7_contact_form',
					) ) : '',
				),

			)
		);
	}

	// Setting fields for WooCommerce
	if ( function_exists( 'WC' ) ) {
		$panels['woocommerce'] = array(
			'priority' => 80,
			'title'    => esc_html__( 'Woocommerce', 'naix' ),
		);

		$sections['catalog'] = array(
			'title'       => esc_html__( 'General', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		);

		$sections['page_header_shop'] = array(
			'title'       => esc_html__( 'Catalog Page Header', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'capability'  => 'edit_theme_options',
			'panel'       => 'woocommerce',
		);

		$sections['shop_badge'] = array(
			'title'       => esc_html__( 'Badges', 'naix' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		);

		$sections['single_product'] = array(
			'title'       => esc_html__( 'Single Product', 'naix' ),
			'description' => '',
			'priority'    => 90,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		);

		$fields = array_merge(
			$fields, array(
				'page_header_shop'            => array(
					'type'        => 'toggle',
					'default'     => 1,
					'label'       => esc_html__( 'Enable Page Header', 'naix' ),
					'section'     => 'page_header_shop',
					'description' => esc_html__( 'Enable to show a page header for catalog page below the site header', 'naix' ),
					'priority'    => 20,
				),
				'page_header_layout_shop'     => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Page Header Layout', 'naix' ),
					'section'         => 'page_header_shop',
					'default'         => '1',
					'priority'        => 20,
					'choices'         => array(
						'1' => esc_html__( 'Layout 1', 'naix' ),
						'2' => esc_html__( 'Layout 2', 'naix' ),
					),
					'active_callback' => array(
						array(
							'setting'  => 'page_header_shop',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'page_header_slider_shop'     => array(
					'type'            => 'repeater',
					'label'           => esc_html__( 'Sliders Content', 'naix' ),
					'section'         => 'page_header_shop',
					'default'         => '',
					'priority'        => 40,
					'row_label'       => array(
						'type'  => 'text',
						'value' => esc_html__( 'Slider', 'naix' ),
					),
					'fields'          => array(
						'title'    => array(
							'type'    => 'textarea',
							'label'   => esc_html__( 'Title', 'naix' ),
							'default' => '',
						),
						'desc'     => array(
							'type'    => 'textarea',
							'label'   => esc_html__( 'Description', 'naix' ),
							'default' => '',
						),
						'image'    => array(
							'type'    => 'image',
							'label'   => esc_html__( 'Image', 'naix' ),
							'default' => '',
						),
						'link_url' => array(
							'type'    => 'text',
							'label'   => esc_html__( 'Link(URL)', 'naix' ),
							'default' => '',
						),
					),
					'active_callback' => array(
						array(
							'setting'  => 'page_header_layout_shop',
							'operator' => '==',
							'value'    => '2',
						),
						array(
							'setting'  => 'page_header_shop',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'page_header_slider_bot_text' => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Bottom Text', 'naix' ),
					'default'         => '',
					'section'         => 'page_header_shop',
					'priority'        => 40,
					'active_callback' => array(
						array(
							'setting'  => 'page_header_layout_shop',
							'operator' => '==',
							'value'    => '2',
						),
						array(
							'setting'  => 'page_header_shop',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'page_header_slider_autoplay' => array(
					'type'            => 'number',
					'label'           => esc_html__( 'Sliders Autoplay', 'naix' ),
					'default'         => 0,
					'section'         => 'page_header_shop',
					'priority'        => 40,
					'description'     => esc_html__( 'Duration of animation between slides (in ms). Enter the value is 0 or empty if you want the slider is not autoplay', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'page_header_layout_shop',
							'operator' => '==',
							'value'    => '2',
						),
						array(
							'setting'  => 'page_header_shop',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'catalog_layout'              => array(
					'type'        => 'select',
					'label'       => esc_html__( 'Catalog Layout', 'naix' ),
					'default'     => 'full-content',
					'section'     => 'catalog',
					'priority'    => 70,
					'description' => esc_html__( 'Select default layout for catalog.', 'naix' ),
					'choices'     => array(
						'full-content'    => esc_html__( 'No Sidebar', 'naix' ),
						'sidebar-content' => esc_html__( 'Left Sidebar', 'naix' ),
						'content-sidebar' => esc_html__( 'Right Content', 'naix' ),
						'masonry-content' => esc_html__( 'Masonry Content', 'naix' ),
					),
				),
				'shop_toolbar_els1'           => array(
					'type'            => 'multicheck',
					'label'           => esc_html__( 'ToolBar Elements', 'naix' ),
					'section'         => 'catalog',
					'default'         => array( 'breadcrumb', 'result', 'sort_by' ),
					'priority'        => 70,
					'choices'         => array(
						'breadcrumb' => esc_html__( 'BreadCrumb', 'naix' ),
						'result'     => esc_html__( 'Result Count', 'naix' ),
						'sort_by'    => esc_html__( 'Sort By', 'naix' ),
					),
					'description'     => esc_html__( 'Select which elements you want to show.', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'catalog_layout',
							'operator' => 'in',
							'value'    => array( 'full-content', 'sidebar-content', 'content-sidebar' ),
						),
					),
				),
				'shop_cats_slug'              => array(
					'type'            => 'textarea',
					'section'         => 'catalog',
					'label'           => esc_html__( 'Custom Categories', 'naix' ),
					'description'     => esc_html__( 'Enter the slug of categories you want to show. Divide information with linebreaks (Enter)', 'naix' ),
					'default'         => '',
					'priority'        => 70,
					'active_callback' => array(
						array(
							'setting'  => 'catalog_layout',
							'operator' => 'in',
							'value'    => array( 'masonry-content' ),
						),
					),
				),
				'product_columns'             => array(
					'type'            => 'select',
					'label'           => esc_html__( 'Product Columns Per Page', 'naix' ),
					'section'         => 'catalog',
					'default'         => '4',
					'priority'        => 80,
					'choices'         => array(
						'4' => esc_html__( '4 Columns', 'naix' ),
						'6' => esc_html__( '6 Columns', 'naix' ),
						'3' => esc_html__( '3 Columns', 'naix' ),
					),
					'description'     => esc_html__( 'Specify how many product columns you want to show on catalog page', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'catalog_layout',
							'operator' => 'in',
							'value'    => array( 'full-content', 'sidebar-content', 'content-sidebar' ),
						),
					),
				),
				'products_per_page'           => array(
					'type'        => 'number',
					'label'       => esc_html__( 'Product Numbers Per Page', 'naix' ),
					'section'     => 'catalog',
					'default'     => 12,
					'priority'    => 90,
					'description' => esc_html__( 'Specify how many products you want to show on catalog page', 'naix' ),
				),
				'shop_nav_type'               => array(
					'type'     => 'select',
					'label'    => esc_html__( 'Type of Navigation', 'naix' ),
					'section'  => 'catalog',
					'default'  => 'numbers',
					'priority' => 90,
					'choices'  => array(
						'numbers'  => esc_html__( 'Page Numbers', 'naix' ),
						'infinite' => esc_html__( 'Infinite Scroll', 'naix' ),
					),
				),

				//Badge
				'show_badges'                 => array(
					'type'        => 'toggle',
					'label'       => esc_html__( 'Show Badges', 'naix' ),
					'section'     => 'shop_badge',
					'default'     => 1,
					'priority'    => 20,
					'description' => esc_html__( 'Check this to show badges on every products.', 'naix' ),
				),
				'badges'                      => array(
					'type'            => 'multicheck',
					'label'           => esc_html__( 'Badges', 'naix' ),
					'section'         => 'shop_badge',
					'default'         => array( 'hot', 'new', 'sale', 'outofstock' ),
					'priority'        => 20,
					'choices'         => array(
						'hot'        => esc_html__( 'Hot', 'naix' ),
						'new'        => esc_html__( 'New', 'naix' ),
						'sale'       => esc_html__( 'Sale', 'naix' ),
						'outofstock' => esc_html__( 'Out Of Stock', 'naix' ),
					),
					'description'     => esc_html__( 'Select which badges you want to show', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'show_badges',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),
				'hot_text'                    => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Custom Hot Text', 'naix' ),
					'section'         => 'shop_badge',
					'default'         => 'Hot',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'show_badges',
							'operator' => '==',
							'value'    => 1,
						),
						array(
							'setting'  => 'badges',
							'operator' => 'contains',
							'value'    => 'hot',
						),
					),
				),
				'outofstock_text'             => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Custom Out Of Stock Text', 'naix' ),
					'section'         => 'shop_badge',
					'default'         => 'Out Of Stock',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'show_badges',
							'operator' => '==',
							'value'    => 1,
						),
						array(
							'setting'  => 'badges',
							'operator' => 'contains',
							'value'    => 'outofstock',
						),
					),
				),
				'new_text'                    => array(
					'type'            => 'text',
					'label'           => esc_html__( 'Custom New Text', 'naix' ),
					'section'         => 'shop_badge',
					'default'         => 'New',
					'priority'        => 20,
					'active_callback' => array(
						array(
							'setting'  => 'show_badges',
							'operator' => '==',
							'value'    => 1,
						),
						array(
							'setting'  => 'badges',
							'operator' => 'contains',
							'value'    => 'new',
						),
					),
				),
				'product_newness'             => array(
					'type'            => 'number',
					'label'           => esc_html__( 'Product Newness', 'naix' ),
					'section'         => 'shop_badge',
					'default'         => 3,
					'priority'        => 20,
					'description'     => esc_html__( 'Display the "New" badge for how many days?', 'naix' ),
					'active_callback' => array(
						array(
							'setting'  => 'show_badges',
							'operator' => '==',
							'value'    => 1,
						),
						array(
							'setting'  => 'badges',
							'operator' => 'contains',
							'value'    => 'new',
						),
					),
				),
				// Single Product
				'product_page_no_bg'          => array(
					'type'        => 'toggle',
					'label'       => esc_html__( 'Product Page No Background', 'naix' ),
					'section'     => 'single_product',
					'default'     => 0,
					'priority'    => 20,
					'description' => esc_html__( 'Check this option to disable background in the product page.', 'naix' ),
				),
				'show_product_meta'           => array(
					'type'        => 'multicheck',
					'label'       => esc_html__( 'Show Product Meta', 'naix' ),
					'section'     => 'single_product',
					'default'     => array( 'sku', 'categories', 'tags' ),
					'priority'    => 40,
					'choices'     => array(
						'sku'        => esc_html__( 'SKU', 'naix' ),
						'categories' => esc_html__( 'Categories', 'naix' ),
						'tags'       => esc_html__( 'Tags', 'naix' ),
					),
					'description' => esc_html__( 'Select which product meta you want to show in single product page', 'naix' ),
				),
				'product_upsells'             => array(
					'type'     => 'toggle',
					'label'    => esc_html__( 'Show Up-sells Products', 'naix' ),
					'section'  => 'single_product',
					'default'  => 1,
					'priority' => 40,
				),
				'upsells_products_columns'    => array(
					'type'        => 'select',
					'label'       => esc_html__( 'Up-sells Products Columns', 'naix' ),
					'section'     => 'single_product',
					'default'     => '4',
					'priority'    => 40,
					'description' => esc_html__( 'Specify how many columns of up-sells products you want to show on single product page', 'naix' ),
					'choices'     => array(
						'3' => esc_html__( '3 Columns', 'naix' ),
						'4' => esc_html__( '4 Columns', 'naix' ),
						'5' => esc_html__( '5 Columns', 'naix' ),
						'6' => esc_html__( '6 Columns', 'naix' ),
					),
				),
				'upsells_products_numbers'    => array(
					'type'        => 'number',
					'label'       => esc_html__( 'Up-sells Products Numbers', 'naix' ),
					'section'     => 'single_product',
					'default'     => 6,
					'priority'    => 40,
					'description' => esc_html__( 'Specify how many numbers of up-sells products you want to show on single product page', 'naix' ),
				),
				'product_related'             => array(
					'type'     => 'toggle',
					'label'    => esc_html__( 'Show Related Products', 'naix' ),
					'section'  => 'single_product',
					'default'  => 1,
					'priority' => 40,
				),
				'related_products_columns'    => array(
					'type'        => 'select',
					'label'       => esc_html__( 'Related Products Columns', 'naix' ),
					'section'     => 'single_product',
					'default'     => '4',
					'priority'    => 40,
					'description' => esc_html__( 'Specify how many columns of related products you want to show on single product page', 'naix' ),
					'choices'     => array(
						'3' => esc_html__( '3 Columns', 'naix' ),
						'4' => esc_html__( '4 Columns', 'naix' ),
						'5' => esc_html__( '5 Columns', 'naix' ),
						'6' => esc_html__( '6 Columns', 'naix' ),
					),
				),
				'related_products_numbers'    => array(
					'type'        => 'number',
					'label'       => esc_html__( 'Related Products Numbers', 'naix' ),
					'section'     => 'single_product',
					'default'     => 6,
					'priority'    => 40,
					'description' => esc_html__( 'Specify how many numbers of related products you want to show on single product page', 'naix' ),
				),
			)
		);
	}

	$settings['panels']   = apply_filters( 'naix_customize_panels', $panels );
	$settings['sections'] = apply_filters( 'naix_customize_sections', $sections );
	$settings['fields']   = apply_filters( 'naix_customize_fields', $fields );

	return $settings;

}

/**
 * init customize
 *
 * @return array
 */


$naix_customize = new Naix_Customize( naix_customize_settings() );

// Fix downloaded fonts from Google.
if ( defined( 'KIRKI_VERSION' ) && version_compare( KIRKI_VERSION, '5.0.0', '<=' ) ) {

	/**
	 * Change the http request headers of 'user-agent' to download .woff2 fonts frm Google.
	 *
	 * @param  array $args
	 * @param  string $url
	 *
	 * @return array
	 */
	function naix_fix_kirki_fonts_request_headers( $args, $url ) {
		if ( false === strpos( $url, 'https://fonts.googleapis.com/css' ) ) {
			return $args;
		}

		if ( isset( $args['user-agent'] ) && $args['user-agent'] == 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_5) AppleWebKit/603.3.8 (KHTML, like Gecko) Version/10.1.2 Safari/603.3.8' ) {
			$args['user-agent'] = 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:73.0) Gecko/20100101 Firefox/73.0';
		}

		return $args;
	}

	add_filter( 'http_request_args', 'naix_fix_kirki_fonts_request_headers', 10, 2 );

	/**
	 * Fix incorrect fonts files downloaded from Google.
	 * Delete the Kirki's transients to force downloading font files again.
	 *
	 * @return void
	 */
	function naix_fix_kirki_fonts() {
		delete_transient( 'kirki_remote_url_contents' );
	}

	add_action( 'after_switch_theme', 'naix_fix_kirki_fonts' );
	add_action( 'wp_ajax_kirki_clear_font_cache', 'naix_fix_kirki_fonts' );
}