<?php
/**
 * Hooks for template archive
 *
 * @package Naix
 */


/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @since 1.0
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function naix_setup_author() {
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}

add_action( 'wp', 'naix_setup_author' );

function naix_excerpt_more( $more ) {
	$more = '&hellip;';

	return $more;
}

add_filter( 'excerpt_more', 'naix_excerpt_more' );

/**
 * Set order by get posts
 *
 * @since  1.0
 *
 * @param object $query
 *
 * @return string
 */
function naix_pre_get_posts( $query ) {
	if ( is_admin() ) {
		return;
	}

	if ( ! $query->is_main_query() ) {
		return;
	}

	if ( $query->is_archive() ) {
		if ( naix_is_portfolio() ) {
			$number = intval( naix_get_option( 'portfolio_per_page' ) );
			$query->set( 'posts_per_page', $number );
		} elseif ( naix_is_catalog() ) {
			$number = intval( naix_get_option( 'products_per_page' ) );
			$query->set( 'posts_per_page', $number );
		}
	}
}

add_action( 'pre_get_posts', 'naix_pre_get_posts' );

/**
 * Change length of the excerpt
 *
 * @since  1.0
 *
 * @param string $length
 *
 * @return string
 */
function naix_excerpt_length( $length ) {
	if ( naix_is_blog() || is_search() ) {
		$excerpt_length = intval( naix_get_option( 'blog_excerpt_length' ) );
		if ( $excerpt_length > 0 ) {
			return $excerpt_length;
		}
	}

	return $length;
}

add_filter( 'excerpt_length', 'naix_excerpt_length' );

/**
 * The archive title
 *
 * @since  1.0
 *
 * @param  array $title
 *
 * @return mixed
 */
function naix_the_archive_title( $title ) {
	if ( is_search() ) {
		$title = sprintf( esc_html__( 'Search Results', 'naix' ) );
	} elseif ( is_404() ) {
		$title = sprintf( esc_html__( 'Page Not Found', 'naix' ) );
	} elseif ( is_page() ) {
		$title = get_the_title();
	} elseif ( is_home() && is_front_page() ) {
		$title = esc_html__( 'The Latest Posts', 'naix' );
	} elseif ( is_home() && ! is_front_page() ) {
		$title = get_the_title( get_option( 'page_for_posts' ) );
	} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
		$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
	} elseif ( function_exists( 'is_product' ) && is_product() ) {
		$title = get_the_title();
	} elseif ( is_single() ) {
		$title = get_the_title();
	} elseif ( is_post_type_archive( 'portfolio_project' ) ) {
		$title = get_the_title( get_option( 'drf_portfolio_page_id' ) );
	} elseif ( is_tax() || is_category() ) {
		$title = single_term_title( '', false );
	}

	if ( get_option( 'woocommerce_shop_page_id' ) ) {
		if ( is_front_page() && ( get_option( 'woocommerce_shop_page_id' ) == get_option( 'page_on_front' ) ) ) {
			$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
		}
	}


	return $title;
}

add_filter( 'get_the_archive_title', 'naix_the_archive_title', 30 );

/**
 * Add entry format for single post
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_entry_format' ) ) :
	function naix_single_entry_format() {

		if ( ! is_singular( 'post' ) ) {
			return;
		}

		if ( naix_single_post_style() != '1' ) {
			return;
		}
		echo '<div class="col-md-12 col-sm-12 col-xs-12">';
		naix_entry_single_thumbnail();
		echo '</div>';
	}
endif;

add_action( 'naix_before_single_post_content', 'naix_single_entry_format' );

/**
 * Add entry format for single post
 *
 * @since  1.0
 *
 *
 */
if ( ! function_exists( 'naix_single_entry_format_top' ) ) :
	function naix_single_entry_format_top() {
		if ( ! is_singular( 'post' ) ) {
			return;
		}

		if ( naix_single_post_style() != '2' ) {
			return;
		}
		echo '<div class="single-post-header">';

		echo '<div class="entry-header">';
		the_title( '<h1 class="entry-title">', '</h1>' );

		echo '<div class="entry-metas">';
		naix_single_posted_on();
		echo '</div>';

		echo '</div>';

		naix_entry_single_thumbnail();
		echo '</div>';
	}
endif;

add_action( 'naix_after_header', 'naix_single_entry_format_top', 100 );


/**
 * Add blog categories
 *
 * @since  1.0
 *
 *
 */
if ( ! function_exists( 'naix_blog_text_categories' ) ) :
	function naix_blog_text_categories() {
		if ( naix_get_option( 'blog_layout' ) != 'text' ) {
			return;
		}

		echo '<div class="col-md-4 col-sm-4 col-xs-12">';
		naix_taxs_list();
		echo '</div>';
	}
endif;

add_action( 'naix_before_post_list', 'naix_blog_text_categories' );


/**
 * Get Blog featured
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_blog_featured' ) ) :
	function naix_blog_featured() {

		if ( ! naix_is_blog() ) {
			return;
		}

		if ( naix_get_option( 'blog_layout' ) != 'text' ) {
			return;
		}

		$query = new WP_Query(
			array(
				'posts_per_page' => 1,
				'tag'            => 'featured'
			)
		);

		$output = '';
		while ( $query->have_posts() ) : $query->the_post();
			$image  = get_the_post_thumbnail_url();
			$bg_css = '';
			if ( $image ) {
				$bg_css = 'style="background-image:url(' . esc_url( $image ) . ')"';
			}
			$categories = get_the_category();
			if ( ! empty( $categories ) ) {
				$output .= '<a class="cat-title" href="' . esc_url( get_category_link( $categories[0]->term_id ) ) . '">' . esc_html( $categories[0]->name ) . '</a>';
			}
			$output .= sprintf(
				'<h2><a href="%s" class="post-title">' .
				'%s' .
				'</a></h2>',
				esc_url( get_the_permalink() ),
				get_the_title()
			);

			$output = sprintf(
				'<div class="naix-post-featured">' .
				'<div class="featured-image" %s></div>' .
				'<div class="post-featured-content parallax" id="naix-post-featured-content">' .
				'<div class="container">' .
				'%s' .
				'</div>' .
				'</div>' .
				'</div>',
				$bg_css,
				$output
			);

			break;
		endwhile;
		wp_reset_postdata();

		echo ! empty( $output ) ? $output : '';

	}

endif;

add_action( 'naix_after_header', 'naix_blog_featured' );


/**
 * Get sidebar left for home split
 *
 * @since  1.0
 *
 */
if ( ! function_exists( 'naix_home_split_sidebar' ) ) :
	function naix_home_split_sidebar() {

		if ( ! is_page_template( 'template-home-split.php' ) ) {
			return;
		}

		echo '<div class="home-split-sidebar">';

		$image_id  = get_post_meta( get_the_ID(), 'home_split_bg_image', true );
		$image     = $image_id ? wp_get_attachment_image_src( $image_id, 'full' ) : '';
		$image_src = $image ? $image[0] : '';
		echo '<div class="featured-img" style="background-image: url(' . $image_src . ')"></div>';

		$socials = get_post_meta( get_the_ID(), 'home_split_socials', true );


		naix_get_socials_html( $socials );

		echo '</div>';

	}
endif;

add_action( 'naix_after_header', 'naix_home_split_sidebar' );

/**
 * Get portfolio description
 *
 * @since  1.0
 *
 */

if ( ! function_exists( 'naix_portfolio_description' ) ) :
	function naix_portfolio_description() {
		if ( ! naix_is_portfolio() ) {
			return '';
		}

		if ( ! intval( naix_get_option( 'enable_portfolio_desc' ) ) ) {
			return '';
		}

		$desc = do_shortcode( wp_kses( naix_get_option( 'portfolio_desc' ), wp_kses_allowed_html( 'post' ) ) );

		if ( is_tax( 'portfolio_category' ) ) {
			$queried_object = get_queried_object();
			if ( $queried_object ) {
				$term_desc = term_description( $queried_object->term_id, 'portfolio_category' );

				$desc = $term_desc ? $term_desc : $desc;
			}
		}

		if ( $desc ) {
			echo '<div class="naix-portfolio-desc">' . $desc . '</div>';
		}

	}

endif;

add_action( 'naix_before_portfolio_content', 'naix_portfolio_description', 20 );


/**
 * Get portfolio categories filter
 *
 * @since  1.0
 *
 */

if ( ! function_exists( 'naix_portfolio_cats_filter' ) ) :
	function naix_portfolio_cats_filter() {

		if ( ! is_post_type_archive( 'portfolio_project' ) ) {
			return '';
		}

		if ( ! naix_get_option( 'portfolio_cats_filter' ) ) {
			return '';
		}

		$filters  = '';
		$output   = array();
		$number   = intval( naix_get_option( 'portfolio_cats_number' ) );
		$taxonomy = 'portfolio_category';

		$nav_type = naix_get_option( 'portfolio_nav_type' );

		if ( $nav_type == 'links' ) {
			$cats = array();
			global $wp_query;

			while ( $wp_query->have_posts() ) {
				$wp_query->the_post();
				$post_categories = wp_get_post_terms( get_the_ID(), $taxonomy );


				foreach ( $post_categories as $cat ) {
					if ( empty( $cats[ $cat->term_id ] ) ) {
						$cats[ $cat->term_id ] = array( 'name' => $cat->name, 'slug' => $cat->slug, );
					}
				}
			}

			$i = 1;
			foreach ( $cats as $category ) {
				if ( $i > $number ) {
					break;
				}
				$i ++;
				$filters .= sprintf( '<li><a href="#filter" data-option-value=".%s-%s">%s</a></li>', esc_attr( $taxonomy ), esc_attr( $category['slug'] ), esc_html( $category['name'] ) );
			}
		} else {
			$term_id = 0;

			if ( is_tax( $taxonomy ) ) {

				$queried_object = get_queried_object();
				if ( $queried_object ) {
					$term_id = $queried_object->term_id;
				}
			}

			$args       = array(
				'parent'  => $term_id,
				'number'  => $number,
				'orderby' => 'count',
				'order'   => 'desc'
			);
			$categories = get_terms( $taxonomy, $args );


			if ( $categories ) {
				foreach ( $categories as $cat ) {
					$filters .= sprintf( '<li><a href="#filter" data-option-value=".%s-%s">%s</a></li>', esc_attr( $taxonomy ), esc_attr( $cat->slug ), esc_html( $cat->name ) );
				}
			}
		}

		if ( $filters ) {
			$output[] = sprintf(
				'<ul class="option-set" data-option-key="filter">
				<li><a href="#filter" class="selected" data-option-value="*">%s</a></li>
				 %s
			</ul>',
				esc_html__( 'All', 'naix' ),
				$filters
			);
		}


		echo '<div id="portfolio-cats-filter" class="portfolio-cats-filter">' . implode( "\n", $output ) . '</div>';

	}

endif;

add_action( 'naix_before_portfolio_content', 'naix_portfolio_cats_filter', 30 );

/**
 * Get portfolio loop
 *
 * @since  1.0
 *
 */

if ( ! function_exists( 'naix_portfolio_loop' ) ) :
	function naix_portfolio_loop() {
		global $naix_portfolio_loop, $wp_query;;

		$naix_portfolio_loop['portfolio_layout']  = naix_get_option( 'portfolio_layout' );
		$naix_portfolio_loop['current_portfolio'] = $wp_query->current_post;
		if ( naix_get_option( 'portfolio_layout' ) == 'grid' ) {
			$naix_portfolio_loop['portfolio_class'] = 'col-md-6 col-sm-6 col-xs-6';
			if ( naix_get_option( 'portfolio_grid_style' ) != '1' ) {
				$naix_portfolio_loop['hover_style'] = naix_get_option( 'portfolio_grid_hover_style' );
			}

			if ( naix_get_option( 'portfolio_grid_columns' ) == '3' ) {
				$naix_portfolio_loop['portfolio_class'] = 'col-md-4 col-sm-6 col-xs-6';
			} elseif ( naix_get_option( 'portfolio_grid_columns' ) == '4' ) {
				$naix_portfolio_loop['portfolio_class'] = 'col-lg-3 col-md-4 col-sm-6 col-xs-6';
			}
		} elseif ( naix_get_option( 'portfolio_layout' ) == 'masonry' ) {
			if ( naix_get_option( 'portfolio_masonry_style' ) != '4' ) {
				$naix_portfolio_loop['hover_style'] = naix_get_option( 'portfolio_masonry_hover_style' );
			}

			if ( naix_get_option( 'portfolio_masonry_style' ) == '1' ) {
				$naix_portfolio_loop['size'] = 'naix-portfolio-grid';
				$mod                         = $wp_query->current_post % 13;
				if ( $mod == 3 || $mod == 5 || $mod == 7 ) {
					$naix_portfolio_loop['size'] = 'naix-portfolio-masonry1';
				}

				$naix_portfolio_loop['portfolio_class'] = 'col-md-3 col-sm-6 col-xs-12';
			} elseif ( naix_get_option( 'portfolio_masonry_style' ) == '2' ) {
				$naix_portfolio_loop['size'] = 'naix-portfolio-grid';
				$mod                         = $wp_query->current_post % 8;
				if ( in_array( $mod, array( 1, 3, 4, 5 ) ) ) {
					$naix_portfolio_loop['size'] = 'naix-portfolio-masonry2';
				}

				$naix_portfolio_loop['portfolio_class'] = 'col-md-4 col-sm-6 col-xs-6';
			} elseif ( naix_get_option( 'portfolio_masonry_style' ) == '3' ) {
				$naix_portfolio_loop['size']            = 'naix-portfolio-grid';
				$mod                                    = $wp_query->current_post % 8;
				$naix_portfolio_loop['portfolio_class'] = 'col-md-12 col-sm-12 col-xs-12';
				if ( in_array( $mod, array( 0, 5 ) ) ) {
					$naix_portfolio_loop['size']            = 'naix-portfolio-masonry3';
					$naix_portfolio_loop['portfolio_class'] = 'portfolio-full';
				} elseif ( $mod == 2 ) {
					$naix_portfolio_loop['size']            = 'naix-portfolio-masonry1';
					$naix_portfolio_loop['portfolio_class'] = 'portfolio-long';
				} elseif ( $mod == 4 ) {
					$naix_portfolio_loop['size']            = 'naix-portfolio-masonry4';
					$naix_portfolio_loop['portfolio_class'] = 'portfolio-wide';
				}
			} elseif ( naix_get_option( 'portfolio_masonry_style' ) == '4' ) {
				$naix_portfolio_loop['size']            = 'naix-portfolio-masonry5';
				$naix_portfolio_loop['portfolio_class'] = 'col-md-4 col-sm-6 col-xs-12';
			}
		} elseif ( naix_get_option( 'portfolio_layout' ) == 'list' ) {
			$naix_portfolio_loop['portfolio_class'] = 'col-md-12 col-sm-12 col-xs-12';
		} elseif ( naix_get_option( 'portfolio_layout' ) == 'free' ) {
			$naix_portfolio_loop['hover_style'] = naix_get_option( 'portfolio_free_hover_style' );

			$naix_portfolio_loop['size']            = 'naix-portfolio-free1';
			$naix_portfolio_loop['portfolio_class'] = '';
			$mod                                    = $wp_query->current_post % 8;
			if ( in_array( $mod, array( 1, 3 ) ) ) {
				$naix_portfolio_loop['size']            = 'naix-portfolio-free2';
				$naix_portfolio_loop['portfolio_class'] = 'portfolio-wide';
			} elseif ( $mod == 2 ) {
				$naix_portfolio_loop['size']            = 'naix-portfolio-free3';
				$naix_portfolio_loop['portfolio_class'] = 'portfolio-full';
			}
		}

	}

endif;

add_action( 'naix_portfolio_loop', 'naix_portfolio_loop' );

/**
 * Add page header for single porfolio
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_page_header' ) ) :
	function naix_single_portfolio_page_header() {
		if ( ! is_singular( 'portfolio_project' ) ) {
			return;
		}

		$portfolio_layout = naix_single_portfolio_layout();
		if ( ! in_array( $portfolio_layout, array( '1', '2' ) ) ) {
			return;
		}

		if ( ! intval( naix_get_option( 'single_portfolio_page_header' ) ) ) {
			return;
		}

		echo '<div class="single-portfolio-header">';

		$image_id  = get_post_meta( get_the_ID(), 'page_header_image', true );
		$image     = wp_get_attachment_image_src( $image_id, 'full' );
		$thumb_url = $image ? $image[0] : '';

		if ( empty( $thumb_url ) ) {
			$thumb_url = naix_get_option( 'single_portfolio_page_header_image' );
		}

		echo sprintf( '<div class="featured-image" style="background-image:url(%s)"></div>', esc_url( $thumb_url ) );

		echo '<div class="entry-header">';
		if ( $portfolio_layout != '2' ) :
			the_title( '<h1 class="entry-title">', '</h1>' );
			$term_list = wp_get_post_terms( get_the_ID(), 'portfolio_category', array( 'fields' => 'names' ) );

			if ( $term_list ) {
				echo sprintf( '<span class="entry-cats">%s</span>', $term_list[0] );
			}

		endif;

		echo '</div>';

		echo '</div>';
	}

endif;

add_action( 'naix_after_header', 'naix_single_portfolio_page_header' );

/**
 * Add page title for single porfolio
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_title' ) ) :
	function naix_single_portfolio_title() {
		if ( ! is_singular( 'portfolio_project' ) ) {
			return;
		}

		$portfolio_layout = naix_single_portfolio_layout();
		if ( ! in_array( $portfolio_layout, array( '3', '4' ) ) ) {
			return;
		}


		echo '<div class="single-portfolio-header">';
		echo '<div class="container">';
		echo '<div class="row">';

		if ( $portfolio_layout == '3' ) {
			echo '<div class="col-md-10 col-sm-10 col-md-offset-2 col-sm-offset-2">';
		} else {
			echo '<div class="col-md-12 col-sm-12">';
		}

		the_title( '<h1 class="entry-title">', '</h1>' );

		echo '</div>';
		echo '</div>';
		echo '</div>';
		echo '</div>';
	}

endif;

add_action( 'naix_after_header', 'naix_single_portfolio_title' );

/**
 * Add entry header for single porfolio
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_entry_header' ) ) :
	function naix_single_portfolio_entry_header() {
		if ( ! is_singular( 'portfolio_project' ) ) {
			return;
		}

		$portfolio_layout = naix_single_portfolio_layout();
		if ( in_array( $portfolio_layout, array( '1' ) ) ) {
			naix_single_portfolio_attibutes();
		} elseif ( $portfolio_layout == '2' ) {
			naix_single_portfolio_info();
		}
	}
endif;

add_action( 'naix_before_single_portfolio_content', 'naix_single_portfolio_entry_header' );


/**
 * Add portfolio contact for single porfolio
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_contact' ) ) :
	function naix_single_portfolio_contact() {
		if ( ! is_singular( 'portfolio_project' ) ) {
			return;
		}

		if ( naix_single_portfolio_layout() != '2' ) {
			return;
		}

		if ( ! intval( naix_get_option( 'single_portfolio_contact' ) ) ) {
			return;
		}

		$form = naix_get_option( 'single_portfolio_contact_form' );

		if ( empty( $form ) ) {
			return;
		}

		$title = naix_get_option( 'single_portfolio_contact_title' );

		printf( '<div class="footer-contact-form">' );
		printf( '<h3 class="cf-title">%s</h3>', $title );
		print( do_shortcode( '[contact-form-7 id="' . esc_attr( $form ) . '"]' ) );
		printf( '</div>' );
	}

endif;

add_action( 'naix_after_single_portfolio_content', 'naix_single_portfolio_contact', 30 );


/**
 * Add portfolio attributes for single portfolio
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_attributes_info' ) ) :
	function naix_single_portfolio_attributes_info() {
		if ( ! is_singular( 'portfolio_project' ) ) {
			return;
		}

		if ( naix_single_portfolio_layout() != '5' ) {
			return;
		}


		naix_single_portfolio_attibutes();
	}

endif;

add_action( 'naix_after_single_portfolio_content', 'naix_single_portfolio_attributes_info' );