<?php
/**
 * Custom functions for entry.
 *
 * @package Naix
 */

/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_posted_on' ) ) :
	function naix_posted_on() {
		$time_string   = '<time class="entry-date published updated" datetime="%s">%s</time>';
		$time_string   = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);
		$archive_year  = get_the_time( 'Y' );
		$archive_month = get_the_time( 'm' );
		$archive_day   = get_the_time( 'd' );

		$posted_on = '<a href="' . esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ) . '" class="entry-meta" rel="bookmark">' . $time_string . '</a>';

		$posted_on .= '<span class="entry-author entry-meta">' . ' ' . esc_html__( 'by', 'naix' ) . ' ' . '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>';


		$categories_list = get_the_category_list( ', ' );
		if ( $categories_list ) {
			$posted_on .= sprintf( '<span class="cat-links entry-meta">' . esc_html__( ' in %s', 'naix' ) . '</span>', $categories_list );
		}


		echo ! empty( $posted_on ) ? $posted_on : '';
	}

endif;

/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_single_posted_on' ) ) :
	function naix_single_posted_on() {
		global $post;

		$time_string   = '<time class="entry-date published updated" datetime="%s">%s</time>';
		$time_string   = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);
		$archive_year  = get_the_time( 'Y' );
		$archive_month = get_the_time( 'm' );
		$archive_day   = get_the_time( 'd' );

		$author_id = $post->post_author;

		$posted_on =
			'<span class="entry-author entry-meta"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID', $author_id ) ) ) . '">' . esc_html( get_the_author_meta( 'display_name', $author_id ) ) . '</a></span>';

		$posted_on .= '<a href="' . esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ) . '" class="entry-meta" rel="bookmark">' . $time_string . '</a>';


		$categories_list = get_the_category_list( ', ' );
		if ( $categories_list ) {
			$posted_on .= sprintf( '<span class="cat-links entry-meta">' . esc_html__( ' %s', 'naix' ) . '</span>', $categories_list );
		}


		echo ! empty( $posted_on ) ? $posted_on : '';
	}

endif;

/**
 * Prints HTML with meta information for the categories, tags and comments.
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_entry_footer' ) ) :
	function naix_entry_footer() {
		// Hide category and tag text for pages.
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', ', ' );
		if ( $tags_list ) {
			printf( '<span class="tags-links"><strong>' . esc_html__( 'Tags', 'naix' ) . ': </strong>%1$s</span>', $tags_list );
		}

	}

endif;

/**
 * Get or display limited words from given string.
 * Strips all tags and shortcodes from string.
 *
 * @since 1.0.0
 *
 * @param integer $num_words The maximum number of words
 * @param string $more More link.
 * @param bool $echo Echo or return output
 *
 * @return string|void Limited content.
 */


if ( ! function_exists( 'naix_content_limit' ) ) :
	function naix_content_limit( $num_words, $more = "&hellip;", $echo = true ) {
		$content = get_the_content();

		// Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'naix_content_limit_allowed_tags', '<script>,<style>' ) );

		// Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = wp_trim_words( $content, $num_words );

		if ( $more ) {
			$output = sprintf(
				'<p>%s <a href="%s" class="more-link" title="%s">%s</a></p>',
				$content,
				get_permalink(),
				sprintf( esc_html__( 'Continue reading &quot;%s&quot;', 'naix' ), the_title_attribute( 'echo=0' ) ),
				esc_html( $more )
			);
		} else {
			$output = sprintf( '<p>%s</p>', $content );
		}

		if ( ! $echo ) {
			return $output;
		}

		echo ! empty( $output ) ? $output : '';
	}

endif;


/**
 * Show entry thumbnail base on its format
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_entry_thumbnail' ) ) :
	function naix_entry_thumbnail( $size = 'thumbnail' ) {
		$html = '';

		$css_class   = '';
		$post_layout = get_post_format();
		if ( $post_layout ) {
			$css_class = 'format-' . get_post_format();
		}
		$html      = get_the_post_thumbnail( get_the_ID(), $size );
		$css_image = '';
		if ( in_array( naix_get_option( 'blog_layout' ), array( 'sidebar-content', 'content-sidebar' ) ) ) {
			if ( naix_get_option( 'blog_nav_type' ) == 'view_more' ) {
				global $wp_query;
				if ( $wp_query->current_post == 0 ) {
					$html      .= get_the_post_thumbnail( get_the_ID(), 'naix-blog-grid', array( 'class' => 'image-second' ) );
					$css_image = 'has-images';
				}
			}

		}
		$html = sprintf( '<a href="%s" class="%s">%s</a>', esc_url( get_the_permalink() ), esc_attr( $css_image ), $html );

		if ( $html ) {
			$html = sprintf( '<div  class="entry-format %s">%s</div>', esc_attr( $css_class ), $html );
		}

		echo apply_filters( __FUNCTION__, $html, get_post_format() );
	}

endif;

/**
 * Show entry thumbnail base on its format for single post
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_entry_single_thumbnail' ) ) :
	function naix_entry_single_thumbnail( $size = 'full' ) {
		$html          = '';
		$featured_type = naix_get_option( 'single_post_featured_image' );
		$css_class     = '';
		$post_layout   = get_post_format();
		if ( $post_layout ) {
			$css_class = 'format-' . get_post_format();
		}
		switch ( $post_layout ) {
			case 'gallery':
				$image_ids = get_post_meta( get_the_ID(), 'images', false );

				if ( empty( $image_ids ) ) {
					if ( $featured_type == '1' ) {
						$image_url = get_the_post_thumbnail_url( get_the_ID(), $size );
						if ( $image_url ) {
							$html .= sprintf(
								'<div class="parallax featured-image-post" style="background-image: url(%s)">' .
								'</div>',
								esc_url( $image_url )
							);
						}
					} else {
						$image = get_the_post_thumbnail( get_the_ID(), $size );
						$html  .= sprintf(
							'<div class="featured-image">' .
							'%s' .
							'</div>',
							$image
						);
					}
					break;

				}

				$gallery = array();
				foreach ( $image_ids as $id ) {
					if ( $featured_type == '1' ) {
						$image = wp_get_attachment_image_src( $id, $size );
						if ( $image ) {
							$gallery[] = '<li style="background-image: url(' . esc_url( $image[0] ) . '">' . '</li>';
						}
					} else {
						$image = wp_get_attachment_image( $id, $size );
						if ( $image ) {
							$gallery[] = '<li class="no-bg">' . $image . '</li>';
						}
					}

				}
				$html .= '<ul class="slides">' . implode( '', $gallery ) . '</ul>';
				break;

			case
			'video':
				$video = get_post_meta( get_the_ID(), 'video', true );

				if ( ! $video ) {
					break;
				}

				$video_html = '';

				// If URL: show oEmbed HTML
				if ( filter_var( $video, FILTER_VALIDATE_URL ) ) {
					if ( $oembed = @wp_oembed_get( $video, array( 'width' => 1170 ) ) ) {
						$video_html = $oembed;
					} else {
						$atts = array(
							'src'   => $video,
							'width' => 1170,
						);

						if ( has_post_thumbnail() ) {
							$atts['poster'] = get_the_post_thumbnail_url( get_the_ID(), 'full' );
						}
						$video_html = wp_video_shortcode( $atts );
					}
				} // If embed code: just display
				else {
					$video_html = $video;
				}

				$html .= '<div class="container">' . $video_html . '</div>';

				break;

			default:
				if ( $featured_type == '1' ) {
					$image_url = get_the_post_thumbnail_url( get_the_ID(), $size );
					if ( $image_url ) {
						$html .= sprintf(
							'<div class="parallax featured-image-post" style="background-image: url(%s)">' .
							'</div>',
							esc_url( $image_url )
						);
					}
				} else {
					$image = get_the_post_thumbnail( get_the_ID(), $size );
					$html  .= sprintf(
						'<div class="featured-image">' .
						'%s' .
						'</div>',
						$image
					);
				}
				break;
		}

		if ( $html ) {
			$html = sprintf( '<div id="naix-single-entry-format"  class="entry-single-format %s">%s</div>', esc_attr( $css_class ), $html );
		}

		echo apply_filters( __FUNCTION__, $html, get_post_format() );
	}

endif;


/**
 * Check is blog
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_is_blog' ) ) :
	function naix_is_blog() {
		if ( ( is_archive() || is_author() || is_category() || is_home() || is_tag() ) && 'post' == get_post_type() ) {
			return true;
		}

		return false;
	}

endif;

/**
 * Check is catalog
 *
 * @return bool
 */
if ( ! function_exists( 'naix_is_catalog' ) ) :
	function naix_is_catalog() {

		if ( function_exists( 'is_shop' ) && ( is_shop() || is_product_category() || is_product_tag() ) ) {
			return true;
		}

		return false;
	}
endif;

/**
 * Check is portfolio
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_is_portfolio' ) ) :
	function naix_is_portfolio() {
		if ( is_post_type_archive( 'portfolio_project' ) || is_tax( 'portfolio_category' ) ) {
			return true;
		}

		return false;
	}
endif;

/**
 * Get blog description
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_blog_description' ) ) :
	function naix_blog_description() {

		if ( ! naix_is_blog() ) {
			return;
		}

		if ( naix_get_option( 'blog_layout' ) != 'text' ) {
			return;
		}

		$blog_text = do_shortcode( wp_kses( naix_get_option( 'blog_text_desc' ), wp_kses_allowed_html( 'post' ) ) );

		if ( is_category() ) {
			if ( $cat_desc = category_description() ) {
				$blog_text = $cat_desc;
			}
		}

		if ( empty( $blog_text ) ) {
			return;
		}

		printf( '<div class="page-desc">%s</div>', $blog_text );
	}

endif;
/**
 * Check is homepage
 *
 * @since  1.0
 */

if ( ! function_exists( 'naix_is_homepage' ) ) :
	function naix_is_homepage() {
		if ( is_page_template( 'template-home-split.php' ) ||
		     is_page_template( 'template-home-without-footer.php' ) ||
		     is_page_template( 'template-homepage.php' )
		) {
			return true;
		}

		return false;
	}

endif;

/**
 * show categories filter
 *
 * @return string
 */

if ( ! function_exists( 'naix_taxs_list' ) ) :
	function naix_taxs_list( $taxonomy = 'category' ) {

		$cats   = '';
		$output = array();
		$number = apply_filters( 'naix_categories_numbers_filter', 9 );

		$args = array(
			'number'  => $number,
			'orderby' => 'count',
			'order'   => 'DESC',

		);

		$term_id = 0;

		if ( is_tax( $taxonomy ) || is_category() ) {

			$queried_object = get_queried_object();
			if ( $queried_object ) {
				$term_id = $queried_object->term_id;
			}
		}


		$found      = false;
		$categories = get_terms( $taxonomy, $args );
		if ( ! is_wp_error( $categories ) && $categories ) {
			foreach ( $categories as $cat ) {
				$cat_selected = '';
				if ( $cat->term_id == $term_id ) {
					$cat_selected = 'selected';
					$found        = true;
				}
				$cats .= sprintf( '<li><a href="%s" class="%s">%s</a></li>', esc_url( get_term_link( $cat ) ), esc_attr( $cat_selected ), esc_html( $cat->name ) );
			}
		}

		$cat_selected = $found ? '' : 'selected';

		if ( $cats ) {
			$blog_url = get_page_link( get_option( 'page_for_posts' ) );
			if ( 'posts' == get_option( 'show_on_front' ) ) {
				$blog_url = home_url();
			}

			if ( $taxonomy == 'portfolio_category' ) {
				$blog_url = get_page_link( get_option( 'drf_portfolio_page_id' ) );
			}
			$output[] = sprintf(
				'<ul>
				<li><a href="%s" class="%s">%s</a></li>
				 %s
			</ul>',
				esc_url( $blog_url ),
				esc_attr( $cat_selected ),
				esc_html__( 'All', 'naix' ),
				$cats
			);
		}

		if ( $output ) {
			echo '<div class="naix-taxs-list">' . implode( "\n", $output ) . '</div>';
		}

	}

endif;

/**
 * Get portfolio attributes
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_attibutes' ) ) :
	function naix_single_portfolio_attibutes( $echo = true ) {

		if ( ! intval( naix_get_option( 'single_portfolio_attr' ) ) ) {
			return;
		}

		$output = array();

		$client      = get_post_meta( get_the_ID(), 'portfolio_client', true );
		$client_text = naix_get_option( 'single_portfolio_client_text' );


		$team      = get_post_meta( get_the_ID(), 'portfolio_team', true );
		$team_text = naix_get_option( 'single_portfolio_team_text' );

		$services      = get_post_meta( get_the_ID(), 'portfolio_services', true );
		$services_text = naix_get_option( 'single_portfolio_services_text' );

		if ( $client ) {
			$output[] = sprintf(
				'<div class="col-item col-md-3 col-sm-3 col-xs-12">' .
				'<div class="attribute-item">' .
				'<label>%s</label>' .
				'<p>%s</p>' .
				'</div>' .
				'</div>',
				esc_html( $client_text ),
				$client
			);
		}

		$output[] = sprintf(
			'<div class="col-item col-md-3 col-sm-3 col-xs-12">' .
			'<div class="attribute-item">' .
			'<label>%s</label>' .
			'<p>%s</p>' .
			'</div>' .
			'</div>',
			esc_html__( 'Date', 'naix' ),
			get_the_date()
		);

		if ( $team ) {
			$output[] = sprintf(
				'<div class="col-item col-md-3 col-sm-3 col-xs-12">' .
				'<div class="attribute-item">' .
				'<label>%s</label>' .
				'<p>%s</p>' .
				'</div>' .
				'</div>',
				esc_html( $team_text ),
				$team
			);
		}

		if ( $services ) {
			$output[] = sprintf(
				'<div class="col-item col-md-3 col-sm-3 col-xs-12">' .
				'<div class="attribute-item">' .
				'<label>%s</label>' .
				'<p>%s</p>' .
				'</div>' .
				'</div>',
				esc_html( $services_text ),
				$services
			);
		}

		$html = sprintf(
			'<div class="entry-attributes">' .
			'<div class="container">' .
			'<div class="row">' .
			'%s' .
			'</div>' .
			'</div>' .
			'</div>',
			implode( ' ', $output )
		);

		if ( $echo ) {
			echo ! empty( $html ) ? $html : '';
		} else {
			return $html;
		}

	}

endif;

/**
 * Get portfolio informarion
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_info' ) ) :
	function naix_single_portfolio_info() {
		$attr_bg_color = naix_get_option( 'single_portfolio_attr_bg_color' );
		$attr_bg_image = naix_get_option( 'single_portfolio_attr_bg_image' );
		$attr_text     = naix_get_option( 'single_portfolio_attr_text' );

		if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
			if ( $custom_attr_image = get_post_meta( get_the_ID(), 'attributes_bg_image', true ) ) {
				$image         = wp_get_attachment_image_src( $custom_attr_image, 'full' );
				$image_src     = $image ? $image[0] : '';
				$attr_bg_image = $image_src;
			}

			if ( $custom_attr_color = get_post_meta( get_the_ID(), 'attributes_bg_color', true ) ) {
				$attr_bg_color = $custom_attr_color;
			}

			if ( $custom_attr_text = get_post_meta( get_the_ID(), 'attributes_text_color', true ) ) {
				$attr_text = $custom_attr_text;
			}

		}

		$style = '';

		if ( $attr_bg_color ) {
			$style = 'background-color:' . esc_attr( $attr_bg_color );
		}

		if ( $attr_bg_image ) {
			$style .= ';background-image:url(' . esc_url( $attr_bg_image ) . ')';
		}

		$attr_text = $attr_text ? 'text-' . $attr_text : '';

		$output = array();

		$term_list = wp_get_post_terms( get_the_ID(), 'portfolio_category', array( 'fields' => 'names' ) );

		if ( $term_list ) {
			$output[] = sprintf( '<span class="entry-cats">%s</span>', $term_list[0] );
		}

		$output[] = sprintf( '<h1 class="entry-title">%s</h1>', get_the_title() );

		$output[] = naix_single_portfolio_attibutes( false );

		echo sprintf(
			'<div class="naix-portfolio-info %s" style="%s">' .
			'<div class="container">' .
			'%s' .
			'</div>' .
			'</div>',
			esc_attr( $attr_text ),
			esc_attr( $style ),
			implode( ' ', $output )
		);

	}
endif;

/**
 * Get single portfolio layout
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_portfolio_layout' ) ) :
	function naix_single_portfolio_layout() {
		$portfolio_layout = naix_get_option( 'single_portfolio_layout' );

		if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
			$portfolio_layout = get_post_meta( get_the_ID(), 'portfolio_layout', true );
		}

		return $portfolio_layout;
	}

endif;

/**
 * Get single post style
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'naix_single_post_style' ) ) :
	function naix_single_post_style() {
		$style = naix_get_option( 'single_post_style' );

		if ( get_post_meta( get_the_ID(), 'custom_style', true ) ) {
			$style = get_post_meta( get_the_ID(), 'post_style', true );
		}

		return $style;
	}

endif;

/**
 * Print HTML of language switcher
 * It requires plugin WPML installed
 */

if ( ! function_exists( 'naix_language_switcher' ) ) :
	function naix_language_switcher( $show_name = false ) {
		$language_dd = '';
		if ( function_exists( 'icl_get_languages' ) ) {
			$languages = icl_get_languages();
			if ( $languages ) {
				$lang_list = array();
				$current   = '';
				foreach ( (array) $languages as $code => $language ) {
					if ( ! $language['active'] ) {
						$lang_list[] = sprintf(
							'<li class="%s"><a href="%s">%s</a></li>',
							esc_attr( $code ),
							esc_url( $language['url'] ),
							$show_name ? esc_html( $language['translated_name'] ) : esc_html( $code )
						);
					} else {
						$current = $language;
						array_unshift(
							$lang_list, sprintf(
								'<li class="active %s"><a href="%s">%s</a></li>',
								esc_attr( $code ),
								esc_url( $language['url'] ),
								$show_name ? esc_html( $language['translated_name'] ) : esc_html( $code )
							)
						);
					}
				}

				$language_dd = sprintf(
					'<span class="current">%s<span class="toggle-children i-icon arrow_carrot-down"></span></span>' .
					'<ul>%s</ul>',
					$show_name ? esc_html( $current['translated_name'] ) : esc_html( $current['language_code'] ),
					implode( "\n\t", $lang_list )
				);
			}
		}

		return $language_dd;
		?>

		<?php
	}
endif;

/**
 * Get blog meta
 *
 * @since  1.0
 *
 * @return string
 */

if ( ! function_exists( 'naix_get_post_meta' ) ) :
	function naix_get_post_meta( $meta ) {

		if ( is_home() && ! is_front_page() ) {
			$post_id = get_queried_object_id();

			return get_post_meta( $post_id, $meta, true );
		}

		if ( is_post_type_archive( 'portfolio_project' ) ) {
			$post_id = intval( get_option( 'drf_portfolio_page_id' ) );

			return get_post_meta( $post_id, $meta, true );
		}

		if ( ! is_singular() ) {
			return false;
		}

		return get_post_meta( get_the_ID(), $meta, true );

	}
endif;

/**
 * Get breadcrumbs
 *
 * @since  1.0.0
 *
 * @return string
 */

if ( ! function_exists( 'naix_get_breadcrumbs' ) ) :
	function naix_get_breadcrumbs() {
		ob_start();
		?>
        <nav class="breadcrumbs">
			<?php
			naix_breadcrumbs(
				array(
					'before'   => '',
					'taxonomy' => function_exists( 'is_woocommerce' ) && is_woocommerce() ? 'product_cat' : 'category',
				)
			);
			?>
        </nav>
		<?php
		echo ob_get_clean();
	}

endif;

/**
 * Get current page URL for layered nav items.
 * @return string
 */
if ( ! function_exists( 'naix_get_page_base_url' ) ) :
	function naix_get_page_base_url() {
		if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
			$link = home_url();
		} elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id( 'shop' ) ) ) {
			$link = get_post_type_archive_link( 'product' );
		} elseif ( is_product_category() ) {
			$link = get_term_link( get_query_var( 'product_cat' ), 'product_cat' );
		} elseif ( is_product_tag() ) {
			$link = get_term_link( get_query_var( 'product_tag' ), 'product_tag' );
		} else {
			$queried_object = get_queried_object();
			$link           = get_term_link( $queried_object->slug, $queried_object->taxonomy );
		}

		return $link;
	}
endif;

/**
 * Display products link
 *
 * @since 1.0
 */

if ( ! function_exists( 'naix_products_links' ) ) :
	function naix_products_links() {

		if ( ! function_exists( 'is_product' ) ) {
			return;
		}

		if ( ! is_product() ) {
			return;
		}

		$prev_link = '<span class="icon-arrow-left"></span>';
		$next_link = '<span class="icon-arrow-right"></span>';

		?>
        <div class="products-links">
			<?php
			previous_post_link( '<div class="nav-previous">%link</div>', $prev_link );
			next_post_link( '<div class="nav-next">%link</div>', $next_link );
			?>
        </div>
		<?php
	}

endif;